CreateDatabaseMetadataCommitter

Trait CreateDatabaseMetadataCommitter 

pub trait CreateDatabaseMetadataCommitter: Send + Sync {
    // Required method
    fn commit<'life0, 'life1, 'life2, 'life3, 'life4, 'async_trait>(
        &'life0 self,
        catalog: &'life1 str,
        schema: &'life2 str,
        value: &'life3 SchemaNameValue,
        creator: &'life4 CreatorGrantIntent,
    ) -> Pin<Box<dyn Future<Output = Result<AtomicCreateOutcome, BoxedError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait,
             'life2: 'async_trait,
             'life3: 'async_trait,
             'life4: 'async_trait;
}
Commits database metadata and any required creator access atomically.

Implementations classify conditional-write failures with AtomicCreateOutcome so the procedure can retry without overwriting concurrent user changes.

Required Methods

fn commit<'life0, 'life1, 'life2, 'life3, 'life4, 'async_trait>( &'life0 self, catalog: &'life1 str, schema: &'life2 str, value: &'life3 SchemaNameValue, creator: &'life4 CreatorGrantIntent, ) -> Pin<Box<dyn Future<Output = Result<AtomicCreateOutcome, BoxedError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait, 'life2: 'async_trait, 'life3: 'async_trait, 'life4: 'async_trait,

Implementors